@@ -5,7 +5,7 @@ use warnings;
 use vars qw[$VERSION %utilities];
 use Module::CoreList;
 
-$VERSION = '5.20170531';
+$VERSION = '5.20170621';
 
 sub utilities {
     my $perl = shift;
@@ -1270,6 +1270,13 @@ my %delta = (
         removed => {
         }
     },
+    5.027001 => {
+        delta_from => 5.027000,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 %utilities = Module::CoreList::_undelta(\%delta);
